# RPCLayout

A simple way to make a Discord rich presence with API using JSON parser to make it.
Includes a multiple functions to help in the development with apis json.

We had some issues importing the code... Trying to fix it...

# Repositories Used
[pypresence](https://github.com/qwertyquerty/pypresence)
[RotMGRPC](https://github.com/neopkr/RotMGRPC)

## Requires:
requests